/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: TaxonomyChanger.java,v 00606b281085 2010/08/07 20:18:17 fabrizio $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.mobile.android.test.functional;

import javax.annotation.Nonnull;
import java.util.concurrent.Callable;
import it.tidalwave.bluebill.mobile.android.R;
import it.tidalwave.bluebill.mobile.android.observation.ObservationActivityTestHelper;
import android.test.ActivityInstrumentationTestCase2;
import com.jayway.android.robotium.solo.Solo;
import it.tidalwave.bluebill.mobile.android.preferences.PreferencesActivityTestHelper;
import it.tidalwave.bluebill.mobile.android.taxonomy.browser.TaxonomyPicker;
import it.tidalwave.bluebill.mobile.android.taxonomy.browser.TaxonomyPickerActivityTestHelper;
import it.tidalwave.semantic.AsSupport;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: $
 *
 **********************************************************************************************************************/
public class TaxonomyChanger extends AsSupport implements Callable<Void>
  {
    @Nonnull
    private final ObservationActivityTestHelper observationActivity;

    @Nonnull
    private final PreferencesActivityTestHelper preferencesActivity;

    @Nonnull
    private final TaxonomyPickerActivityTestHelper taxonomyPickerActivity;

    @Nonnull
    private final Solo solo;

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public TaxonomyChanger (final @Nonnull ActivityInstrumentationTestCase2 instrumentationTestCase,
                            final @Nonnull Solo solo,
                            final @Nonnull Object ... capabilities)
      {
        super(capabilities);
        this.solo = solo;
        observationActivity    = new ObservationActivityTestHelper(instrumentationTestCase, solo);
        preferencesActivity    = new PreferencesActivityTestHelper(instrumentationTestCase, solo);
        taxonomyPickerActivity = new TaxonomyPickerActivityTestHelper(instrumentationTestCase, solo);
      }

    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    public Void call()
      throws Exception
      {
        observationActivity.waitForActivity();
        observationActivity.invokeMenuAction(R.id.preferences);

        preferencesActivity.clickOnCheckListSelector();

        taxonomyPickerActivity.waitForActivity();
        as(TaxonomyPicker.class).pickTaxonomy(taxonomyPickerActivity);
        // TODO: if the taxonomy has been changed, wait for the progress indicator to disappear

        solo.waitForDialogToClose(30000L); // TODO: also assert it's a progress indicator
        solo.goBack();

        observationActivity.waitForActivity();

        return null;
      }
  }
